@@ -68,15 +68,25 @@ def read_xls(
                 if col_value is None:
                     pass
                 else:
-                    if col_name in data_cols_cols:
-                        col_value = xlrd.xldate_as_datetime(col_value, 0).strftime(date_cols[col_name])  # 转换为datatime后转换为需要的格式
-                    else:
-                        if len(data_cols_cols) == 0 and auto_conv_date is True:
-                            if col_type == 3:
+                    if col_type == 3:
+                        if col_name in data_cols_cols:
+                            col_value = xlrd.xldate_as_datetime(col_value, 0).strftime(date_cols[col_name])  # 转换为datatime后转换为需要的格式
+                        else:
+                            if len(data_cols_cols) == 0 and auto_conv_date is True:
                                 col_value = xlrd.xldate_as_datetime(col_value, 0).strftime('%Y-%m-%d %H:%M:%S')
                             else:
                                 pass
+                    else:
+                        pass
                 each_row_data[col_name] = col_value
+            each_row_data_single = list(set(each_row_data.values()))
+            if len(each_row_data_single) == 1:
+                if each_row_data_single[0] is None:
+                    continue  # 去除全空值
+                else:
+                    pass
+            else:
+                pass
             sheet_data_list.append(each_row_data)  # 将每一行的数据dict组织到当前sheet的数据list中
         table_data_dict[each_sheet.name] = sheet_data_list  # 将每个sheet的数据组织到table_data_dict里面
     return table_data_dict
@@ -143,11 +153,15 @@ def read_xlsx(
                                 pass
                     else:
                         pass
-                        # if col_name in data_cols_cols:
-                        #     col_value = xlrd.xldate_as_datetime(col_value, 0).strftime(date_cols[col_name])  # 转换为datatime后转换为需要的格式
-                        # else:
-                        #     pass
                 each_row_data[col_name] = col_value
+            each_row_data_single = list(set(each_row_data.values()))
+            if len(each_row_data_single) == 1:
+                if each_row_data_single[0] is None:
+                    continue  # 去除全空值
+                else:
+                    pass
+            else:
+                pass
             sheet_data_list.append(each_row_data)  # 将每一行的数据dict组织到当前sheet的数据list中
         table_data_dict[each_sheet.title] = sheet_data_list  # 将每个sheet的数据组织到table_data_dict里面
     return table_data_dict
@@ -295,3 +309,9 @@ def save(
     else:
         print(':( file is not supported')
         return
+
+
+if __name__ == '__main__':
+    read(
+        file='/Users/zeroseeker/Library/Containers/com.tencent.WeWorkMac/Data/Documents/Profiles/322626BB34F0F7A7AE1AB82B6523D997/Caches/Files/2022-03/ce4f40521272e323c22598a556492563/王佳 3月24日 每日必跑.xlsx'
+    )
\ No newline at end of file
